@@ -18,21 +18,18 @@ from typing import Any, BinaryIO, Callable, NamedTuple, TypeVar, Union, cast
 from PIL import Image
 from PIL.ImageCms import ImageCmsProfile
 
-from pikepdf import (
+from pikepdf import jbig2
+from pikepdf._core import Buffer, Pdf, PdfError, StreamDecodeLevel
+from pikepdf._exceptions import DependencyError
+from pikepdf.models import _transcoding
+from pikepdf.objects import (
     Array,
     Dictionary,
     Name,
     Object,
-    Pdf,
-    PdfError,
     Stream,
-    StreamDecodeLevel,
     String,
-    jbig2,
 )
-from pikepdf._core import Buffer
-from pikepdf._exceptions import DependencyError
-from pikepdf.models import _transcoding
 
 T = TypeVar('T')
 
@@ -683,10 +680,10 @@ class PdfImage(PdfImageBase):
         Images might be saved as any of .png, .jpg, or .tiff.
 
         Examples:
-            >>> im.extract_to(stream=bytes_io)
+            >>> im.extract_to(stream=bytes_io)  # doctest: +SKIP
             '.png'
 
-            >>> im.extract_to(fileprefix='/tmp/image00')
+            >>> im.extract_to(fileprefix='/tmp/image00')  # doctest: +SKIP
             '/tmp/image00.jpg'
 
         Args:
@@ -1023,7 +1020,7 @@ class PdfInlineImage(PdfImageBase):
 
         # ...externalize it,
         tmppdf.pages[0].externalize_inline_images()
-        raw_img = next(im for im in tmppdf.pages[0].images.values())
+        raw_img = cast(Stream, next(im for im in tmppdf.pages[0].images.values()))
 
         # ...then use the regular PdfImage API to extract it.
         img = PdfImage(raw_img)
