@@ -9,7 +9,7 @@ import logging
 import re
 import sys
 from abc import ABC, abstractmethod
-from datetime import datetime
+from datetime import datetime, timezone
 from functools import wraps
 from io import BytesIO
 from typing import TYPE_CHECKING, Any, Callable, NamedTuple, Set
@@ -18,9 +18,9 @@ from warnings import warn
 from lxml import etree
 from lxml.etree import QName, XMLSyntaxError
 
-from .. import Name, Stream, String
-from .. import __version__ as pikepdf_version
-from .._xml import parse_xml
+from pikepdf._version import __version__ as pikepdf_version
+from pikepdf._xml import parse_xml
+from pikepdf.objects import Name, Stream, String
 
 if sys.version_info < (3, 9):  # pragma: no cover
     from typing import Iterable, MutableMapping
@@ -128,10 +128,11 @@ LANG_ALTS = frozenset(
 re_xml_illegal_chars = re.compile(
     r"(?u)[^\x09\x0A\x0D\x20-\U0000D7FF\U0000E000-\U0000FFFD\U00010000-\U0010FFFF]"
 )
-re_xml_illegal_bytes = re.compile(
-    br"[^\x09\x0A\x0D\x20-\xFF]|&#0;"
-    # br"&#(?:[0-9]|0[0-9]|1[0-9]|2[0-9]|3[0-1]|x[0-9A-Fa-f]|x0[0-9A-Fa-f]|x1[0-9A-Fa-f]);"
-)
+re_xml_illegal_bytes = re.compile(br"[^\x09\x0A\x0D\x20-\xFF]|&#0;")
+
+# Might want to check re_xml_illegal_bytes for patterns such as:
+# br"&#(?:[0-9]|0[0-9]|1[0-9]|2[0-9]|3[0-1]
+#   |x[0-9A-Fa-f]|x0[0-9A-Fa-f]|x1[0-9A-Fa-f]);"
 
 
 def _parser_basic(xml: bytes):
@@ -259,7 +260,7 @@ class AuthorConverter(Converter):
             return xmp_val
         if xmp_val is None or xmp_val == [None]:
             return None
-        return '; '.join(xmp_val)
+        return '; '.join(author for author in xmp_val if author is not None)
 
 
 class DateConverter(Converter):
@@ -333,7 +334,7 @@ class PdfMetadata(MutableMapping):
 
     Example:
         >>> with pdf.open_metadata() as records:
-                records['dc:title'] = 'New Title'
+        ...     records['dc:title'] = 'New Title'
 
     See Also:
         :meth:`pikepdf.Pdf.open_metadata`
@@ -567,7 +568,7 @@ class PdfMetadata(MutableMapping):
             # We were asked to mark the file as being edited by pikepdf
             self._setitem(
                 QName(XMP_NS_XMP, 'MetadataDate'),
-                datetime.now(datetime.utcnow().astimezone().tzinfo).isoformat(),
+                datetime.now(timezone.utc).isoformat(),
                 applying_mark=True,
             )
             self._setitem(
